package com.srs.stureg.service;

import java.util.List;
import com.srs.stureg.domain.OfflineCheckIn;

/**
 * 现场办理学生信息Service接口
 * 
 * @author 邓
 * @date 2023-05-20
 */
public interface IOfflineCheckInService 
{
    /**
     * 查询现场办理学生信息
     * 
     * @param id 现场办理学生信息主键
     * @return 现场办理学生信息
     */
    public OfflineCheckIn selectOfflineCheckInById(Long id);

    /**
     * 查询现场办理学生信息列表
     * 
     * @param offlineCheckIn 现场办理学生信息
     * @return 现场办理学生信息集合
     */
    public List<OfflineCheckIn> selectOfflineCheckInList(OfflineCheckIn offlineCheckIn);

    /**
     * 新增现场办理学生信息
     * 
     * @param offlineCheckIn 现场办理学生信息
     * @return 结果
     */
    public int insertOfflineCheckIn(OfflineCheckIn offlineCheckIn);

    /**
     * 修改现场办理学生信息
     * 
     * @param offlineCheckIn 现场办理学生信息
     * @return 结果
     */
    public int updateOfflineCheckIn(OfflineCheckIn offlineCheckIn);

    /**
     * 批量删除现场办理学生信息
     * 
     * @param ids 需要删除的现场办理学生信息主键集合
     * @return 结果
     */
    public int deleteOfflineCheckInByIds(Long[] ids);

    /**
     * 删除现场办理学生信息信息
     * 
     * @param id 现场办理学生信息主键
     * @return 结果
     */
    public int deleteOfflineCheckInById(Long id);
}
